summaryrefslogtreecommitdiff
path: root/examples/adhoc_user.py
diff options
context:
space:
mode:
Diffstat (limited to 'examples/adhoc_user.py')
-rwxr-xr-xexamples/adhoc_user.py16
1 files changed, 8 insertions, 8 deletions
diff --git a/examples/adhoc_user.py b/examples/adhoc_user.py
index 7df9f793..d4b650bc 100755
--- a/examples/adhoc_user.py
+++ b/examples/adhoc_user.py
@@ -2,9 +2,9 @@
# -*- coding: utf-8 -*-
"""
SleekXMPP: The Sleek XMPP Library
Copyright (C) 2010 Nathanael C. Fritz
- This file is part of SleekXMPP.
+ This file is part of Slixmpp.
See the file LICENSE for copying permission.
"""
@@ -14,28 +14,28 @@ import logging
import getpass
from optparse import OptionParser
-import sleekxmpp
+import slixmpp
# Python versions before 3.0 do not use UTF-8 encoding
# by default. To ensure that Unicode is handled properly
# throughout SleekXMPP, we will set the default encoding
# ourselves to UTF-8.
if sys.version_info < (3, 0):
- from sleekxmpp.util.misc_ops import setdefaultencoding
+ from slixmpp.util.misc_ops import setdefaultencoding
setdefaultencoding('utf8')
else:
raw_input = input
-class CommandUserBot(sleekxmpp.ClientXMPP):
+class CommandUserBot(slixmpp.ClientXMPP):
"""
A simple SleekXMPP bot that uses the adhoc command
provided by the adhoc_provider.py example.
"""
def __init__(self, jid, password, other, greeting):
- sleekxmpp.ClientXMPP.__init__(self, jid, password)
+ slixmpp.ClientXMPP.__init__(self, jid, password)
self.command_provider = other
self.greeting = greeting
@@ -2,9 +2,9 @@
# -*- coding: utf-8 -*-
"""
- SleekXMPP: The Sleek XMPP Library
+ Slixmpp: The Slick XMPP Library
Copyright (C) 2010 Nathanael C. Fritz
@@ -14,28 +14,28 @@ import logging
# Python versions before 3.0 do not use UTF-8 encoding
# by default. To ensure that Unicode is handled properly
-# throughout SleekXMPP, we will set the default encoding
+# throughout Slixmpp, we will set the default encoding
# ourselves to UTF-8.
if sys.version_info < (3, 0):
@@ -14,28 +14,28 @@ import logging
"""
- A simple SleekXMPP bot that uses the adhoc command
+ A simple Slixmpp bot that uses the adhoc command
provided by the adhoc_provider.py example.
"""